@@ -89,6 +89,7 @@ SKIPPED_IMAGES = {
         "kuryr-base",
         "monasca-base",
         "monasca-thresh",
+        "mongodb",
         "nova-mksproxy",
         "ovsdpdk",
         "searchlight-base",
@@ -97,6 +98,7 @@ SKIPPED_IMAGES = {
         "zun-base",
     ],
     'centos+source': [
+        "mongodb",
         "ovsdpdk",
         "tripleoclient",
         # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
@@ -136,6 +138,9 @@ SKIPPED_IMAGES = {
         "zun-base",
     ],
     'ubuntu+source': [
+        # FIXME(yoctozepto): temporary block due to upstream issues
+        "bifrost-base",
+
         "crane",
         "cyborg-base",
         # There is no qdrouterd package for ubuntu bionic
@@ -196,6 +201,7 @@ SKIPPED_IMAGES = {
         "kuryr-base",
         "monasca-base",
         "monasca-thresh",
+        "mongodb",
         "nova-mksproxy",
         "ovsdpdk",
         "rsyslog",
@@ -207,6 +213,7 @@ SKIPPED_IMAGES = {
     ],
     'oraclelinux+source': [
         "bifrost-base",
+        "mongodb",
         "ovsdpdk",
         "rsyslog",
         "tripleoclient",
